@@ -234,7 +234,8 @@ def check_file(spath, file_path, suffix=None):
     files = []
     for f in all_file:
         if os.path.isdir(f):
-            files.extend(check_file(spath, file_path + '\\' + f, suffix=suffix))
+            ff = os.path.join(file_path, f)
+            files.extend(check_file(spath, ff, suffix=suffix))
             os.chdir(file_path)
         else:
             if not suffix:
@@ -455,7 +456,11 @@ class BatchFile:
 if __name__ == "__main__":
     # others please use shutil
     # shutil.copytree()
-    a = BatchFile(r"C:\Users\wangchangxin\Desktop\d1")
-    a.filter_dir_name("a", layer=-1)
-    a.filter_file_name("2")
-    a.to_path(r"C:\Users\wangchangxin\Desktop\d2", add_dir=[-2, -1], flatten=True)
+    # a = BatchFile(r"C:\Users\wangchangxin\Desktop\d1")
+    # a.filter_dir_name("a", layer=-1)
+    # a.filter_file_name("2")
+    # a.to_path(r"C:\Users\wangchangxin\Desktop\d2", add_dir=[-2, -1], flatten=True)
+    bf = BatchFile(r"/home/iap13/wcx/CHG")
+
+    # bf.filter_dir_name(includ="Mo")
+    filenames = bf.file_list
\ No newline at end of file
